@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     He MingYang <hemingyang@uniontech.com>
- *
- * Maintainer: Liu Zheng <liuzheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "RecorderRegionShow.h"
 #include "utils.h"
@@ -54,7 +38,7 @@ RecorderRegionShow::~RecorderRegionShow()
         m_painter = nullptr;
     }
     if (m_cameraWidget) {
-        if (m_cameraWidget->getcameraStatus()) {
+        if (m_cameraWidget->getCameraStatus()) {
             m_cameraWidget->cameraStop();
         }
         delete m_cameraWidget;
@@ -71,7 +55,7 @@ void RecorderRegionShow::initCameraInfo(const CameraWidget::Position position, c
 
     QRect r = this->geometry();
     m_cameraWidget->setFixedSize(size);
-    m_cameraWidget->initCamera();
+    m_cameraWidget->initUI();
     m_cameraWidget->setRecordRect(r.x(), r.y(), r.width(), r.height());
     switch (position) {
     case CameraWidget::Position::rightBottom: {
