@@ -42,23 +42,55 @@ static bool CheckFFmpegEnv()
     bool flag = false;
     QDir dir;
     QString path  = QLibraryInfo::location(QLibraryInfo::LibrariesPath);
+    qDebug() << "QLibraryInfo::LibrariesPath: " << path;
     dir.setPath(path);
     QStringList list = dir.entryList(QStringList() << (QString("libavcodec") + "*"), QDir::NoDotAndDotDot | QDir::Files);
-    qDebug() << list;
+    qDebug() << list << " exists in the " << path;
 
-    if (list.contains("libavcodec.so.58")) {
-        flag = true;
-    }
-
-    //x11下需要检测ffmpeg应用是否存在
-    if (!isWaylandProtocol()) {
-        qInfo() << "Is exists ffmpeg in path(/usr/bin/): " << QFile("/usr/bin/ffmpeg").exists();
-        if (QFile("/usr/bin/ffmpeg").exists()) {
-            flag = true;
-        } else {
-            flag = false;
+    QString libName = "";
+    QRegExp re("libavcodec.so.*"); //Sometimes libavcodec.so may not exist, so find it through regular expression.
+    for (int i = 0; i < list.count(); i++) {
+        if (re.exactMatch(list[i])) {
+            libName = list[i];
+            break;
         }
     }
+    qDebug() << "目录(" << path << ")中存在编码库(" << libName << ")";
+    //是否存在编码库,存在编码库需要继续判断是否存在对应的编码器
+    if (!libName.isEmpty()) {
+        QLibrary libavcodec;
+        libavcodec.setFileName(libName);
+        if (libavcodec.load()) {
+            qDebug() << "编码库加载成功！";
+            typedef AVCodec *(*p_avcodec_find_encoder)(enum AVCodecID id);
+            p_avcodec_find_encoder m_avcodec_find_encoder = nullptr;
+            m_avcodec_find_encoder = reinterpret_cast<p_avcodec_find_encoder>(libavcodec.resolve("avcodec_find_encoder"));
+            AVCodec *pCodec = nullptr;
+            if (m_avcodec_find_encoder) {
+                pCodec = m_avcodec_find_encoder(AV_CODEC_ID_H264);
+            } else {
+                qWarning() << "编码库中无avcodec_find_encoder接口！";
+            }
+            if (pCodec) {
+                qDebug() << "编码器存在 AVCodecID:" << AV_CODEC_ID_H264;
+                flag = true;
+                //x11下需要检测ffmpeg应用是否存在,wayland不需要检查
+                if (!isWaylandProtocol()) {
+                    qInfo() << "Is exists ffmpeg in path(/usr/bin/): " << QFile("/usr/bin/ffmpeg").exists();
+                    if (!QFile("/usr/bin/ffmpeg").exists()) {
+                        flag = false;
+                    }
+                }
+            } else {
+                qWarning() << "Can not find output video encoder! (没有找到合适的编码器！) AVCodecID:" << AV_CODEC_ID_H264;
+            }
+        } else {
+            qWarning() << "编码库加载失败！";
+        }
+    } else {
+        qWarning() << "目录(" << path << ")中不存在编码库(" << libName << ")";
+    }
+
     return flag;
 }
 
@@ -74,14 +106,14 @@ int main(int argc, char *argv[])
 
     // 平板模式
     Utils::isTabletEnvironment = false; // DGuiApplicationHelper::isTabletEnvironment();
-    qDebug() << "Is Table:" << Utils::isTabletEnvironment;
+    //qInfo() << "Is Table:" << Utils::isTabletEnvironment;
 
     // wayland 协议
     Utils::isWaylandMode = isWaylandProtocol();
-    qDebug() << "Is Wayland:" << Utils::isWaylandMode;
+    //qInfo() << "Is Wayland:" << Utils::isWaylandMode;
 
     Utils::isRootUser = (getuid() == 0);
-    qDebug() << "Is Root User:" << Utils::isRootUser;
+    //qInfo() << "Is Root User:" << Utils::isRootUser;
 
     if (Utils::isWaylandMode) {
         qputenv("QT_WAYLAND_SHELL_INTEGRATION", "kwayland-shell");
@@ -93,13 +125,8 @@ int main(int argc, char *argv[])
     //检查是否包含ffmpeg相关库true：包含 false：不包含
     Utils::isFFmpegEnv =  CheckFFmpegEnv();
 //    Utils::isFFmpegEnv = false;
-    qDebug() << "Is Exists FFmpeg Lib:" << Utils::isFFmpegEnv;
+    //qInfo() << "Is Exists FFmpeg Lib:" << Utils::isFFmpegEnv;
 
-#ifdef KF5_WAYLAND_FLAGE_ON
-    qDebug() << "KF5_WAYLAND_FLAGE_ON is open!!";
-#else
-    qDebug() << "KF5_WAYLAND_FLAGE_ON is close!!";
-#endif
     // 适配deepin-turbo 启动加速
 #if(DTK_VERSION < DTK_VERSION_CHECK(5,4,0,0))
     DApplication::loadDXcbPlugin();
@@ -170,18 +197,30 @@ int main(int argc, char *argv[])
 
         // Load translator.
         app->loadTranslator();
-        Screenshot window;
 
         // 主题设置
         DGuiApplicationHelper::ColorType t_type = DGuiApplicationHelper::instance()->themeType();
         DGuiApplicationHelper::instance()->setPaletteType(t_type);
         Utils::themeType = t_type;
 
+        //显示系统信息
+        Utils::showCurrentSys();
+
+        //qInfo() << "截图录屏日志路径: " << Dtk::Core::DLogManager::getlogFilePath().right(Dtk::Core::DLogManager::getlogFilePath().length() - Dtk::Core::DLogManager::getlogFilePath().indexOf(".cache"));
+        qInfo() << "截图录屏版本: " << DApplication::buildVersion(APP_VERSION);
+#ifdef KF5_WAYLAND_FLAGE_ON
+        qInfo() << "KF5_WAYLAND_FLAGE_ON is open!!";
+#else
+        qInfo() << "KF5_WAYLAND_FLAGE_ON is close!!";
+#endif
+        qInfo() << "Is Table:" << Utils::isTabletEnvironment;
+        qInfo() << "Is Wayland:" << Utils::isWaylandMode;
+        qInfo() << "Is Root User:" << Utils::isRootUser;
+        qInfo() << "Is Exists FFmpeg Lib:" << Utils::isFFmpegEnv;
         if (cmdParser.isSet(useGStreamer)) {
             Utils::isFFmpegEnv = false;
         }
 
-
         QString t_launchMode = "screenShot";
         if (cmdParser.isSet(screenRecordOption)) {
             t_launchMode = "screenRecord";
@@ -190,6 +229,7 @@ int main(int argc, char *argv[])
         } else if (cmdParser.isSet(screenScrollOption)) {
             t_launchMode = "screenScroll";
         }
+        Screenshot window;
         window.initLaunchMode(t_launchMode);
         DBusScreenshotService dbusService(&window);
         // Register debus service.
