@@ -1,44 +1,10 @@
-/*
+// Copyright (C) 2019 ~ 2019 Deepin Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
-* Copyright (C) 2019 ~ 2019 Deepin Technology Co., Ltd.
-
-*
-
-* Author:     wangcong <wangcong@uniontech.com>
-
-*
-
-* Maintainer: wangcong <wangcong@uniontech.com>
-
-*
-
-* This program is free software: you can redistribute it and/or modify
-
-* it under the terms of the GNU General Public License as published by
-
-* the Free Software Foundation, either version 3 of the License, or
-
-* any later version.
-
-*
-
-* This program is distributed in the hope that it will be useful,
-
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-
-* GNU General Public License for more details.
-
-*
-
-* You should have received a copy of the GNU General Public License
-
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-*/
 #include "mainwindow.h"
-#include "utils.h"
+#include "putils.h"
 
 #include <QDebug>
 #include <QDBusInterface>
@@ -236,7 +202,7 @@ void MainWindow::saveImg()
     QClipboard *cb = qApp->clipboard();
     cb->setMimeData(t_imageData, QClipboard::Clipboard);
 
-    if (Utils::isWaylandMode) {
+    if (PUtils::isWaylandMode) {
         QEventLoop eventloop;
         connect(cb, SIGNAL(dataChanged()), &eventloop, SLOT(quit()));
         eventloop.exec();
@@ -394,7 +360,7 @@ void MainWindow::mouseMoveEvent(QMouseEvent *event)
             this->setCursor(QCursor(Qt::ClosedHandCursor));
             //qDebug() << "=============event->globalPos()" << event->globalPos() << "dragPosition" << dragPosition;
             QPoint globalPoint = event->globalPos() - dragPosition;
-            if (Utils::isWaylandMode && globalPoint.y() < 0) {
+            if (PUtils::isWaylandMode && globalPoint.y() < 0) {
                 globalPoint.setY(0);
             }
             move(globalPoint);
@@ -497,12 +463,12 @@ bool MainWindow::eventFilter(QObject *watched, QEvent *event)
         if (QEvent::WindowActivate == event->type()) {
             //qDebug() <<this<< m_toolBar << __FUNCTION__ << __LINE__ << event->type();
             //规避wayland下打开贴图1，并在贴图1上重新生成贴图2时，贴图2激活状态不对(工具栏已经设置显示，但实际上未显示。)。
-            if (Utils::isWaylandMode && !isLeftPressDown) {
+            if (PUtils::isWaylandMode && !isLeftPressDown) {
                 this->m_toolBar->setHiden();
             }
             updateToolBarPosition();
             //规避wayland下打开多个贴图，通过鼠标连续切换贴图时，贴图激活状态不对(工具栏已经设置显示，但实际上未显示。)。
-            if (Utils::isWaylandMode && isLeftPressDown) {
+            if (PUtils::isWaylandMode && isLeftPressDown) {
                 this->m_toolBar->setHiden();
             }
             //qDebug() <<this<< m_toolBar << __FUNCTION__ << __LINE__ << event->type();
@@ -652,7 +618,7 @@ void MainWindow::sendNotify(QString savePath, bool bSaveState)
     int timeout = -1;
     unsigned int id = 0;
     QList<QVariant> arg;
-    arg << tr("Pin Screenshots")                 // appname
+    arg << (QCoreApplication::applicationName()) //tr("Pin Screenshots")                 // appname
         << id                                                    // id
         << QString("deepin-screen-recorder")                     // icon
         << tr("Screenshot finished")                              // summary
