@@ -70,8 +70,9 @@ bool WaylandIntegration::isEGLInitialized()
 void WaylandIntegration::stopStreaming()
 {
     qDebug() << "stop recording!";
-    globalWaylandIntegration->stopVideoRecord();
     globalWaylandIntegration->stopStreaming();
+    globalWaylandIntegration->stopVideoRecord();
+    globalWaylandIntegration->m_appendFrameToListFlag = false;
 }
 
 bool WaylandIntegration::WaylandIntegrationPrivate::stopVideoRecord()
@@ -225,14 +226,24 @@ void WaylandIntegration::WaylandIntegrationPrivate::bindOutput(int outputName, i
 
 void WaylandIntegration::WaylandIntegrationPrivate::stopStreaming()
 {
+    qDebug() << "m_streamingEnabled: " << m_streamingEnabled;
     if (m_streamingEnabled) {
-        m_appendFrameToListFlag = false;
         m_streamingEnabled = false;
 
         // First unbound outputs and destroy remote access manager so we no longer receive buffers
         if (m_remoteAccessManager) {
+            qDebug() << "正在释放m_remoteAccessManager...";
+            //qDebug() << "m_remoteAccessManager->startRecording(0):" << m_remoteAccessManager->startRecording(0);
+            qDebug() << "m_remoteAccessManager->startRecording(1):" << m_remoteAccessManager->startRecording(1);
+            //m_remoteAccessManager->startRecording(0);
+            qDebug() << "正在等待最后一帧释放...";
+            QEventLoop loop;
+            connect(this,SIGNAL(lastFrame()),&loop,SLOT(quit()));
+            loop.exec();
+            qDebug() << "最后一帧已释放";
             m_remoteAccessManager->release();
             m_remoteAccessManager->destroy();
+            qDebug() << "m_remoteAccessManager已释放";
         }
         qDeleteAll(m_bindOutputs);
         m_bindOutputs.clear();
@@ -250,6 +261,7 @@ QMap<quint32, WaylandIntegration::WaylandOutput> WaylandIntegration::WaylandInte
 
 void WaylandIntegration::WaylandIntegrationPrivate::initWayland(QStringList list)
 {
+    m_streamingEnabled = true;
     //通过wayland底层接口获取图片的方式不相同，需要获取电脑的厂商，hw的需要特殊处理
     //m_boardVendorType = getBoardVendorType();
     m_boardVendorType = getProductType();
@@ -363,7 +375,8 @@ int WaylandIntegration::WaylandIntegrationPrivate::getProductType()
     if (str_output.contains("KLVV", Qt::CaseInsensitive) ||
             str_output.contains("KLVU", Qt::CaseInsensitive) ||
             str_output.contains("PGUV", Qt::CaseInsensitive) ||
-            str_output.contains("PGUW", Qt::CaseInsensitive))
+            str_output.contains("PGUW", Qt::CaseInsensitive) ||
+            str_output.contains("L540", Qt::CaseInsensitive))
         return 1;
     return 0;
 }
@@ -447,11 +460,14 @@ void WaylandIntegration::WaylandIntegrationPrivate::onDeviceChanged(quint32 name
 void WaylandIntegration::WaylandIntegrationPrivate::processBuffer(const KWayland::Client::RemoteBuffer *rbuf, const QRect rect)
 {
     //qDebug() << Q_FUNC_INFO;
+    qDebug() << ">>>>>> open fd!" << rbuf->fd();
     QScopedPointer<const KWayland::Client::RemoteBuffer> guard(rbuf);
     auto dma_fd = rbuf->fd();
     quint32 width = rbuf->width();
     quint32 height = rbuf->height();
     quint32 stride = rbuf->stride();
+    m_lastFrame = rbuf->frame();
+    qDebug() << "rbuf->frame(): " << rbuf->frame();
     //    if(!bGetFrame())
     //        return;
     if (m_bInitRecordAdmin) {
@@ -499,17 +515,22 @@ void WaylandIntegration::WaylandIntegrationPrivate::processBuffer(const KWayland
     }
     munmap(mapData, stride * height);
     close(dma_fd);
+    qDebug() << ">>>>>> close fd!" << dma_fd;
+    if(m_lastFrame == 0){
+        qDebug() << "是否是最后一帧: " << m_lastFrame;
+        emit lastFrame();
+    }
 }
 
 //根据wayland客户端bufferReady给过来的像素格式，转成QImage的格式
 QImage::Format WaylandIntegration::WaylandIntegrationPrivate::getImageFormat(quint32 format)
 {
-    switch(format){
+    switch (format) {
     case GBM_FORMAT_XRGB8888: //GBM_FORMAT_XRGB8888 = 875713112
-        qDebug() << "fd 图片格式: XRGB"<< GBM_FORMAT_XRGB8888 << " -> " << "QImage::Format_RGB32";
+        qDebug() << "fd 图片格式: XRGB" << GBM_FORMAT_XRGB8888 << " -> " << "QImage::Format_RGB32";
         return QImage::Format_RGB32;
     case GBM_FORMAT_XBGR8888: //GBM_FORMAT_XBGR8888 = 875709016
-        qDebug() << "fd 图片格式: XBGR"<< GBM_FORMAT_XBGR8888 << " -> " << "QImage::Format_RGB32";
+        qDebug() << "fd 图片格式: XBGR" << GBM_FORMAT_XBGR8888 << " -> " << "QImage::Format_RGB32";
         return QImage::Format_RGB32;
     case GBM_FORMAT_RGBX8888: //GBM_FORMAT_RGBX8888 = 875714642
         qDebug() << "fd 图片格式: RGBX" << GBM_FORMAT_RGBX8888 << " -> " << "QImage::Format_RGBX8888";
@@ -518,30 +539,33 @@ QImage::Format WaylandIntegration::WaylandIntegrationPrivate::getImageFormat(qui
         qDebug() << "fd 图片格式: BGRX" << GBM_FORMAT_BGRX8888 << " -> " << "QImage::Format_BGR30";
         return QImage::Format_BGR30;
     case GBM_FORMAT_ARGB8888: //GBM_FORMAT_ARGB8888 = 875713089
-        qDebug() << "fd 图片格式: ARGB"<< GBM_FORMAT_ARGB8888 << " -> " << "QImage::Format_ARGB32";
+        qDebug() << "fd 图片格式: ARGB" << GBM_FORMAT_ARGB8888 << " -> " << "QImage::Format_ARGB32";
         return QImage::Format_ARGB32;
     case GBM_FORMAT_ABGR8888: //GBM_FORMAT_ABGR8888 = 875708993
-        qDebug() << "fd 图片格式: ABGR"<< GBM_FORMAT_ABGR8888 << " -> " << "QImage::Format_ARGB32";
+        qDebug() << "fd 图片格式: ABGR" << GBM_FORMAT_ABGR8888 << " -> " << "QImage::Format_ARGB32";
         return QImage::Format_ARGB32;
     case GBM_FORMAT_RGBA8888: //GBM_FORMAT_RGBA8888 = 875708754
-        qDebug() << "fd 图片格式: RGBA"<< GBM_FORMAT_RGBA8888 << " -> " << "QImage::Format_RGBA8888";
+        qDebug() << "fd 图片格式: RGBA" << GBM_FORMAT_RGBA8888 << " -> " << "QImage::Format_RGBA8888";
         return QImage::Format_RGBA8888;
     case GBM_FORMAT_BGRA8888: //GBM_FORMAT_BGRA8888 = 875708738
-        qDebug() << "fd 图片格式: BGRA"<< GBM_FORMAT_BGRA8888 << " -> " << "QImage::Format_BGR30";
+        qDebug() << "fd 图片格式: BGRA" << GBM_FORMAT_BGRA8888 << " -> " << "QImage::Format_BGR30";
         return QImage::Format_BGR30;
     default:
-        qDebug() << "fd 图片格式未知: "<<format << " -> " << "QImage::Format_RGB32";
+        qDebug() << "fd 图片格式未知: " << format << " -> " << "QImage::Format_RGB32";
         return QImage::Format_RGB32;
     }
 }
 
 void WaylandIntegration::WaylandIntegrationPrivate::processBufferX86(const KWayland::Client::RemoteBuffer *rbuf, const QRect rect)
 {
+    qDebug() << ">>>>>> open fd!" << rbuf->fd();
     QScopedPointer<const KWayland::Client::RemoteBuffer> guard(rbuf);
     auto dma_fd = rbuf->fd();
     quint32 width = rbuf->width();
     quint32 height = rbuf->height();
     quint32 stride = rbuf->stride();
+    m_lastFrame = rbuf->frame();
+    qDebug() << "rbuf->frame(): " << rbuf->frame();
     if (m_bInitRecordAdmin) {
         m_bInitRecordAdmin = false;
         if (Utils::isFFmpegEnv) {
@@ -579,6 +603,11 @@ void WaylandIntegration::WaylandIntegrationPrivate::processBufferX86(const KWayl
         }
     }
     close(dma_fd);
+    qDebug() << ">>>>>> close fd!" << dma_fd;
+    if(m_lastFrame == 0){
+        qDebug() << "是否是最后一帧: " << m_lastFrame;
+        emit lastFrame();
+    }
 }
 //通过线程每30ms钟向数据池中取出一张图片添加到环形缓冲区，以便后续视频编码
 void WaylandIntegration::WaylandIntegrationPrivate::appendFrameToList()
@@ -642,10 +671,10 @@ void WaylandIntegration::WaylandIntegrationPrivate::appendFrameToList()
                 }
             }
             QImage img(m_screenSize, QImage::Format_RGBA8888);
-            if(m_boardVendorType){
-                 //qDebug() << "1 img.format: " << img.format();
-                 img = img.convertToFormat(QImage::Format_RGB32);
-                 //qDebug() << "2 img.format: " << img.format();
+            if (m_boardVendorType) {
+                //qDebug() << "1 img.format: " << img.format();
+                img = img.convertToFormat(QImage::Format_RGB32);
+                //qDebug() << "2 img.format: " << img.format();
             }
             img.fill(Qt::GlobalColor::black);
             QPainter painter(&img);
@@ -773,7 +802,7 @@ void WaylandIntegration::WaylandIntegrationPrivate::setupRegistry()
             qDebug() << "screenGeometry: " << screenGeometry;
             qDebug() << "rbuf->isValid(): " << rbuf->isValid();
             connect(rbuf, &KWayland::Client::RemoteBuffer::parametersObtained, this, [this, rbuf, screenGeometry] {
-                qDebug() << "正在处理buffer...";
+                qDebug() << "正在处理buffer..."<< "fd:" << rbuf->fd() << "frame:" <<rbuf->frame();
                 if (m_boardVendorType)
                 {
                     //arm hw
@@ -783,7 +812,7 @@ void WaylandIntegration::WaylandIntegrationPrivate::setupRegistry()
                     //other
                     processBufferX86(rbuf, screenGeometry);
                 }
-                qDebug() << "buffer已处理";
+                qDebug() << "buffer已处理"<< "fd:" << rbuf->fd();
             });
             qDebug() << "buffer已接收";
         });
