@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     He MingYang <hemingyang@uniontech.com>
- *
- * Maintainer: Liu Zheng <liuzheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "shottoolwidget.h"
 #include "../utils/configsettings.h"
@@ -770,7 +754,7 @@ void ShotToolWidget::initTextLabel()
     t_blurArea->setRadius(15);
     t_blurArea->setMode(DBlurEffectWidget::GaussianBlur);
     t_blurArea->setBlurEnabled(true);
-    t_blurArea->setBlendMode(DBlurEffectWidget::InWindowBlend);
+    t_blurArea->setBlendMode(DBlurEffectWidget::BehindWindowBlend);
     t_blurArea->setMaskColor(QColor(255, 255, 255, 0));
     t_blurArea->setFixedSize(TOOL_SLIDERBlUR_SIZE);
 
@@ -803,12 +787,25 @@ void ShotToolWidget::initTextLabel()
         ConfigSettings::instance()->setValue("text", "fontsize", indexTofontsize[t_value]);
     });
 
+    ToolButton *t_seperator = new ToolButton(this);
+    if (Utils::themeType == 1) {
+        //t_seperator->setStyleSheet("border:1px groove rgba(0, 0, 0, 77);border-radius:0px");
+        t_seperator->setStyleSheet("border:0px solid rgba(0, 0, 0, 77);border-radius:0px;background-color:rgba(0, 0, 0, 77)");
+    } else {
+        //t_seperator->setStyleSheet("border:1px groove rgba(255, 255, 255, 26);border-radius:0px");
+        t_seperator->setStyleSheet("border:0px solid rgba(255, 255, 255, 26);border-radius:0px;background-color:rgba(255, 255, 255, 26)");
+    }
+    t_seperator->setDisabled(true);
+    t_seperator->setFixedSize(SPLITTER_SIZE);
+
     QVBoxLayout *rectLayout = new QVBoxLayout(this);
-    rectLayout->setMargin(3);
+    rectLayout->setMargin(2);
     rectLayout->setSpacing(0);
-    rectLayout->addSpacing(3);
+    rectLayout->addSpacing(0);
 
     rectLayout->addWidget(t_blurArea, Qt::AlignTop);
+    rectLayout->addSpacing(10);
+    rectLayout->addWidget(t_seperator, 0, Qt::AlignHCenter);
 
     m_textSubTool->setLayout(rectLayout);
     addWidget(m_textSubTool);
