@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     Hou Lei <houlei@uniontech.com>
- *
- * Maintainer: Liu Zheng <liuzheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "subtoolwidget.h"
 #include "../utils/audioutils.h"
@@ -340,6 +324,17 @@ void SubToolWidget::initRecordLabel()
 
     m_mouseButton->setMenu(m_cursorMenu);
 
+    ToolButton *seperator3 = new ToolButton(this);
+    if (Utils::themeType != 1) {
+        seperator3->setStyleSheet("border:0px solid rgba(0, 0, 0, 0);border-radius:0px;background-color:rgba(0, 0, 0, 0)");
+    } else {
+        seperator3->setStyleSheet("border:0px solid rgba(255, 255, 255, 0);border-radius:0px;background-color:rgba(255, 255, 255, 0)");
+    }
+    seperator3->setDisabled(true);
+    seperator3->setFixedSize(QSize(5, 30));
+    //添加分割线
+    btnList.append(seperator3);
+
 
     //2019-10-14：新增选项按钮
     m_optionButton = new ToolButton();
@@ -354,11 +349,18 @@ void SubToolWidget::initRecordLabel()
 
     QActionGroup *t_formatGroup = new QActionGroup(this);
     QActionGroup *t_fpsGroup = new QActionGroup(this);
+    //录屏保存位置的组
+    QActionGroup *t_saveGroup = new QActionGroup(this);
     t_formatGroup->setExclusive(true);
     t_fpsGroup->setExclusive(true);
+    t_saveGroup->setExclusive(true);
 
     m_recordOptionMenu = new DMenu(this);
     DFontSizeManager::instance()->bind(m_recordOptionMenu, DFontSizeManager::T8);
+
+    QAction *saveTitleAction = new QAction(m_recordOptionMenu);
+    QAction *saveToDesktopAction = new QAction(m_recordOptionMenu);
+    QAction *saveToVideoAction = new QAction(m_recordOptionMenu);
     //for test
     QAction *formatTitleAction = new QAction(m_recordOptionMenu);
     QAction *gifAction = new QAction(m_recordOptionMenu);
@@ -405,6 +407,15 @@ void SubToolWidget::initRecordLabel()
     t_formatGroup->addAction(mp4Action);
     t_formatGroup->addAction(mkvAction);
 
+    saveTitleAction->setDisabled(true);
+    saveTitleAction->setText(tr("Save to"));
+    saveToDesktopAction->setText(tr("Desktop"));
+    saveToDesktopAction->setCheckable(true);
+    saveToVideoAction->setText(tr("Videos"));
+    saveToVideoAction->setCheckable(true);
+    t_saveGroup->addAction(saveToDesktopAction);
+    t_saveGroup->addAction(saveToVideoAction);
+
     fpsTitleAction->setDisabled(true);
     fpsTitleAction->setText(tr("FPS:"));
     fps5Action->setText(tr("5 fps"));
@@ -424,6 +435,12 @@ void SubToolWidget::initRecordLabel()
     t_fpsGroup->addAction(fps24Action);
     t_fpsGroup->addAction(fps30Action);
 
+    m_recordOptionMenu->addAction(saveTitleAction);
+    m_recordOptionMenu->addAction(saveToDesktopAction);
+    m_recordOptionMenu->addAction(saveToVideoAction);
+
+    m_recordOptionMenu->addSeparator();
+
     m_recordOptionMenu->addAction(formatTitleAction);
 #if !(defined (__mips__) || defined (__sw_64__) || defined (__loongarch_64__))
     if (Utils::isFFmpegEnv) {
@@ -445,6 +462,40 @@ void SubToolWidget::initRecordLabel()
     m_recordOptionMenu->hide();
     m_optionButton->setMenu(m_recordOptionMenu);
 
+    qDebug() << "t_saveIndex: " << ConfigSettings::instance()->value("recordConfig", "save_op_record");
+    SaveAction t_saveIndex = ConfigSettings::instance()->value("recordConfig", "save_op_record").value<SaveAction>();
+    qDebug() << "t_saveIndex: " << t_saveIndex;
+    switch (t_saveIndex) {
+    case SaveToDesktop: {
+        saveToDesktopAction->setChecked(true);
+        ConfigSettings::instance()->setValue("recordConfig", "save_op_record", SaveAction::SaveToDesktop);
+        ConfigSettings::instance()->setValue("recordConfig", "savepath", QStandardPaths::writableLocation(
+                                                 QStandardPaths::DesktopLocation));
+        break;
+    }
+    default:
+        saveToVideoAction->setChecked(true);
+        ConfigSettings::instance()->setValue("recordConfig", "save_op_record", SaveAction::SaveToVideo);
+        ConfigSettings::instance()->setValue("recordConfig", "savepath", QStandardPaths::writableLocation(
+                                                 QStandardPaths::MoviesLocation));
+
+        break;
+    }
+
+    connect(t_saveGroup, QOverload<QAction *>::of(&QActionGroup::triggered),
+    [ = ](QAction * t_act) {
+        if (t_act == saveToDesktopAction) {
+            qDebug() << "save to desktop";
+            ConfigSettings::instance()->setValue("recordConfig", "save_op_record", SaveAction::SaveToDesktop);
+            ConfigSettings::instance()->setValue("recordConfig", "savepath", QStandardPaths::writableLocation(
+                                                     QStandardPaths::DesktopLocation));
+        } else {
+            qDebug() << "save to video";
+            ConfigSettings::instance()->setValue("recordConfig", "save_op_record", SaveAction::SaveToVideo);
+            ConfigSettings::instance()->setValue("recordConfig", "savepath", QStandardPaths::writableLocation(
+                                                     QStandardPaths::MoviesLocation));
+        }
+    });
     // change by hmy
 
     if (t_saveGif == true) {
@@ -672,7 +723,9 @@ void SubToolWidget::initShotLabel()
     m_ocrButton->setFixedSize(MIN_TOOL_BUTTON_SIZE);
     installTipHint(m_ocrButton, tr("Extract Text"));
 #ifdef  OCR_SCROLL_FLAGE_ON
-    btnList.append(m_ocrButton);
+    if (QFile("/usr/bin/deepin-ocr").exists()) {
+        btnList.append(m_ocrButton);
+    }
 #endif
 
     ToolButton *seperator2 = new ToolButton(this);
@@ -761,7 +814,7 @@ void SubToolWidget::initShotLabel()
         seperator3->setStyleSheet("border:0px solid rgba(255, 255, 255, 0);border-radius:0px;background-color:rgba(255, 255, 255, 0)");
     }
     seperator3->setDisabled(true);
-    seperator3->setFixedSize(QSize(3, 30));
+    seperator3->setFixedSize(QSize(5, 30));
     //添加分割线
     btnList.append(seperator3);
 
