@@ -20,7 +20,7 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished"/>
+        <translation>Qeyd aparılır</translation>
     </message>
 </context>
 <context>
@@ -96,10 +96,6 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
         <source>Screenshot</source>
         <translation>Ekran şəkli</translation>
     </message>
-    <message>
-        <source>The screenshot has been saved in the album</source>
-        <translation>Ekran şəkli albomda saxlanıldı</translation>
-    </message>
     <message>
         <source>Screenshot failed.</source>
         <translation>Ekran şəkli çəkilə bilmədi.</translation>
@@ -112,6 +108,10 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
         <source>Pin Screenshots</source>
         <translation>Ekran şəkllərini sancaqlayın</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Qovluğu açın</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -153,6 +153,10 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
         <source>Record</source>
         <translation>Yazmaq</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Qovluğu açın</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -357,6 +361,14 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
         <source>Pin screenshots</source>
         <translation>Ekran şəkllərini sancaqlayın</translation>
     </message>
+    <message>
+        <source>Start OCR</source>
+        <translation>OCR-i başladın</translation>
+    </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>Sürüşdürməni başladın</translation>
+    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -554,6 +566,10 @@ və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
         <source>ogg</source>
         <translation>ogg</translation>
     </message>
+    <message>
+        <source>Videos</source>
+        <translation>Videolar</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
