@@ -98,10 +98,6 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <source>Screenshot</source>
         <translation>Tapadenn-skramm</translation>
     </message>
-    <message>
-        <source>The screenshot has been saved in the album</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Screenshot failed.</source>
         <translation type="unfinished"></translation>
@@ -114,6 +110,10 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <source>Pin Screenshots</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -155,6 +155,10 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <source>Record</source>
         <translation>Enrollañ</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -359,6 +363,14 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <source>Pin screenshots</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Start OCR</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -556,6 +568,10 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <source>ogg</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Videos</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
